gedidb.L2BGranule
=================

.. currentmodule:: gedidb

.. autoclass:: L2BGranule

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L2BGranule.__init__
      ~L2BGranule.beam
      ~L2BGranule.build_virtual_dataset
      ~L2BGranule.clear
      ~L2BGranule.close
      ~L2BGranule.copy
      ~L2BGranule.create_dataset
      ~L2BGranule.create_dataset_like
      ~L2BGranule.create_group
      ~L2BGranule.create_virtual_dataset
      ~L2BGranule.flush
      ~L2BGranule.get
      ~L2BGranule.items
      ~L2BGranule.iter_beams
      ~L2BGranule.keys
      ~L2BGranule.list_beams
      ~L2BGranule.move
      ~L2BGranule.pop
      ~L2BGranule.popitem
      ~L2BGranule.require_dataset
      ~L2BGranule.require_group
      ~L2BGranule.setdefault
      ~L2BGranule.update
      ~L2BGranule.validate_beam_name
      ~L2BGranule.values
      ~L2BGranule.visit
      ~L2BGranule.visit_links
      ~L2BGranule.visititems
      ~L2BGranule.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~L2BGranule.abstract
      ~L2BGranule.attrs
      ~L2BGranule.driver
      ~L2BGranule.file
      ~L2BGranule.filename
      ~L2BGranule.filename_metadata
      ~L2BGranule.id
      ~L2BGranule.libver
      ~L2BGranule.meta_block_size
      ~L2BGranule.mode
      ~L2BGranule.n_beams
      ~L2BGranule.name
      ~L2BGranule.parent
      ~L2BGranule.product
      ~L2BGranule.ref
      ~L2BGranule.regionref
      ~L2BGranule.start_datetime
      ~L2BGranule.swmr_mode
      ~L2BGranule.userblock_size
      ~L2BGranule.uuid
      ~L2BGranule.version_granule
      ~L2BGranule.version_product
   
   